**repomanager** : GitLab Repository Manager 
================================================================================


Latest documentation of repomanager :

  * `repomanager.pdf  <https://gitlab.incoresemi.com/utils/repomanager/-/jobs/artifacts/master/raw/repomanager.pdf?job=doc>`_
